# Snapshot report for `test/js/clientSpecificationTest.js`

The actual snapshot is saved in `clientSpecificationTest.js.snap`.

Generated by [AVA](https://ava.li).

## structure

> Snapshot 1

    ServiceReply {
      clientSpecification: ClientSpecification {
        identifier: 'uuid',
        name: 'awesomeDeviceName',
        namespace: 'app',
        topicDataHost: 'localhost',
        topicDataPortWs: '8668',
        topicDataPortZmq: '8667',
      },
    }
